# Nim's Django Helpers
[![PyPI version](https://badge.fury.io/py/ndh.svg)](https://pypi.org/project/ndh)
[![Build Status](https://travis-ci.org/nim65s/ndh.svg?branch=master)](https://travis-ci.org/nim65s/ndh)
[![Coverage Status](https://coveralls.io/repos/github/nim65s/ndh/badge.svg?branch=master)](https://coveralls.io/github/nim65s/ndh?branch=master)
[![Maintainability](https://api.codeclimate.com/v1/badges/6737a84239590ddc0d1e/maintainability)](https://codeclimate.com/github/nim65s/ndh/maintainability)

## Requirements

- Python 3.6
- Django 2.0
- [django-autoslug](https://github.com/iplweb/django-autoslug-iplweb)
- [django-bootstrap4](https://github.com/zostera/django-bootstrap4)

## Install

`pip install ndh`
